"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault").default;
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.createAuthenticator = void 0;
var _jsonwebtoken = _interopRequireDefault(require("jsonwebtoken"));
var _jwkToPem = _interopRequireDefault(require("jwk-to-pem"));
var _nodeFetch = _interopRequireDefault(require("node-fetch"));
var _error = _interopRequireDefault(require("@webiny/error"));
var _handler = require("@webiny/handler");
// All JWTs are split into 3 parts by two periods
const isJwt = token => token.split(".").length === 3;
const jwksCache = new Map();
const createAuthenticator = config => {
  const getJWKs = async () => {
    const key = config.domain;
    if (!jwksCache.has(key)) {
      const response = await (0, _nodeFetch.default)(`${config.domain}/.well-known/jwks.json`).then(res => res.json());
      jwksCache.set(key, response.keys);
    }
    return jwksCache.get(key);
  };
  const auth0Authenticator = async idToken => {
    if (typeof idToken === "string" && isJwt(idToken)) {
      try {
        const jwks = await getJWKs();
        const decoded = _jsonwebtoken.default.decode(idToken, {
          complete: true
        });
        if (!decoded) {
          return null;
        }
        const {
          header
        } = decoded;
        const jwk = jwks.find(key => key.kid === header.kid);
        if (!jwk) {
          return null;
        }
        return _jsonwebtoken.default.verify(idToken, (0, _jwkToPem.default)(jwk));
      } catch (err) {
        throw new _error.default(err.message, "SECURITY_AUTH0_INVALID_TOKEN");
      }
    }
    return null;
  };
  return new _handler.ContextPlugin(({
    security
  }) => {
    security.addAuthenticator(async idToken => {
      const token = await auth0Authenticator(idToken);
      if (!token) {
        return null;
      }
      return config.getIdentity({
        token
      });
    });
  });
};
exports.createAuthenticator = createAuthenticator;

//# sourceMappingURL=createAuthenticator.js.map