"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.createIdentityType = void 0;
var _plugins = require("@webiny/handler-graphql/plugins");
var _handler = require("@webiny/handler");
const createIdentityType = config => {
  return [
  // Webiny supports different identity types, so we need to define a dedicated GraphQL type
  // for each identity type in the system. They all must implement the base `SecurityIdentity` interface.
  new _plugins.GraphQLSchemaPlugin({
    typeDefs: `
            type ${config.name} implements SecurityIdentity {
                id: ID!
                type: String!
                displayName: String!
                permissions: [JSON!]!
            }
        `,
    resolvers: {
      [config.name]: {
        __isTypeOf(obj) {
          return obj.type === config.identityType;
        }
      }
    }
  }),
  // This plugin is only applied in multi-tenant environments.
  new _handler.ContextPlugin(context => {
    if (context.tenancy.isMultiTenant()) {
      context.plugins.register(new _plugins.GraphQLSchemaPlugin({
        typeDefs: `
                            extend type ${config.name} {
                                currentTenant: Tenant
                                defaultTenant: Tenant
                            }
                        `
      }));
    }
  })];
};
exports.createIdentityType = createIdentityType;

//# sourceMappingURL=createIdentityType.js.map