"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.extendTenancy = void 0;
var _plugins = require("@webiny/handler-graphql/plugins");
var _handler = require("@webiny/handler");
const extendTenancy = () => {
  return new _handler.ContextPlugin(context => {
    // This is only applicable to multi-tenant environments.
    context.waitFor("tenantManager", () => {
      // We can have different "appClientId" for each tenant.
      // This plugin adds the GraphQL fields to allow per-tenant appClientId storage.
      context.plugins.register(new _plugins.GraphQLSchemaPlugin({
        typeDefs: /* GraphQL */`
                        extend input TenantSettingsInput {
                            appClientId: String!
                        }

                        extend type TenantSettings {
                            appClientId: String!
                        }
                        extend type TenancyQuery {
                            appClientId: String
                        }
                    `,
        resolvers: {
          TenancyQuery: {
            appClientId(_, __, context) {
              const tenant = context.tenancy.getCurrentTenant();
              return tenant.settings.appClientId;
            }
          },
          TenantSettings: {
            /**
             * Root tenant will not have the `appClientId` stored in the database,
             * and in TenantSettings type, this field is non-nullable, so we need a fallback value.
             */
            appClientId: tenant => {
              return tenant.appClientId || "";
            }
          }
        }
      }));
    });
  });
};
exports.extendTenancy = extendTenancy;

//# sourceMappingURL=extendTenancy.js.map